@@ -9,16 +9,23 @@ from ..run_together import csv_file_to_file
 class TestCSVFileToFile(unittest.TestCase):
     def setUp(self):
         self.csv_contents = iter([
-            ['a', 'b'],
-            ['c', 'd'],
-            ['e', 'f'],
+            'a,b',
+            'c,d',
+            'e,f',
         ])
+        self.csv_list = (
+            [u'a', u'b'],
+            [u'c', u'd'],
+            [u'e', u'f'],
+        )
 
     @patch('karld.run_together.ensure_dir')
     @patch('karld.run_together.write_as_csv')
-    @patch('karld.run_together.i_get_csv_data')
+    @patch('karld.run_together.i_read_buffered_file')
+    @patch('karld.run_together.csv_reader')
     def test_csv_file_to_file(self,
-                              mock_in_csv,
+                              mock_csv_reader,
+                              mock_file_reader,
                               mock_out_csv,
                               mock_ensure_dir):
         """
@@ -33,7 +40,8 @@ class TestCSVFileToFile(unittest.TestCase):
             return list(islice(rows, 3))
 
         mock_out_csv.side_effect = out_csv
-        mock_in_csv.return_value = self.csv_contents
+        mock_file_reader.return_value = self.csv_contents
+        mock_csv_reader.return_value = self.csv_list
 
         def row_consumer(rows):
             for row in rows:
@@ -53,4 +61,4 @@ class TestCSVFileToFile(unittest.TestCase):
 
         self.assertIn('out/yeah_file.csv', mock_out_csv.call_args[0])
 
-        mock_row_consumer.assert_called_once_with(self.csv_contents)
+        mock_row_consumer.assert_called_once_with(self.csv_list)
